==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/DAL/Uninstall/UninstallDb.php <==
<?php
namespace Claromentis\Core\DAL\Uninstall;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array();
use Claromentis\Core\DAL;




class UninstallDb extends DAL\Db
{
    protected $error;
    protected $tables = array();
    protected $primary_keys = array();
    protected $indexes = array();
    
    
    
    
    protected $real_db;
    public $query_log = array();
    public function __construct(DAL\Db $_8bf9813aed9bb9b6d29793f34cc5e497)
    {
        parent::__construct();
        $this->query_parser = new DAL\QueryParser($_8bf9813aed9bb9b6d29793f34cc5e497);
        $this->real_db = $_8bf9813aed9bb9b6d29793f34cc5e497;
    }
    public function CreateTable($_c81a475ecdc9121925813756400e25f9, $_1d86cbeb8686a6ea980cae523fcc2663, $_2bd53affda468514082256f545d64e34 = false, $_6bfdb3fdd74d9a63f8a8594eeec07b71 = false)
    {
        return $this->real_db->CreateTable($_c81a475ecdc9121925813756400e25f9, $_1d86cbeb8686a6ea980cae523fcc2663, $_2bd53affda468514082256f545d64e34, $_6bfdb3fdd74d9a63f8a8594eeec07b71);
    }
    public function DropTable($_c81a475ecdc9121925813756400e25f9)
    {
        return $this->real_db->DropTable($_c81a475ecdc9121925813756400e25f9);
    }
    public function CreatePrimaryKey($_c81a475ecdc9121925813756400e25f9, ...$_a42c86642011ef739b88ee80672c387d)
    {
        return $this->real_db->CreatePrimaryKey($_c81a475ecdc9121925813756400e25f9, ...$_a42c86642011ef739b88ee80672c387d);
    }
    public function DropPrimaryKey($_c81a475ecdc9121925813756400e25f9)
    {
        return $this->real_db->DropPrimaryKey($_c81a475ecdc9121925813756400e25f9);
    }
    public function CreateIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea, ...$_a42c86642011ef739b88ee80672c387d)
    {
        return true;
    }
    public function DropIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea)
    {
        return $this->real_db->DropIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea);
    }
    public function AddColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_b1ab3509f78a3004fac0e4cc59064b8f)
    {
        return $this->real_db->AddColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_b1ab3509f78a3004fac0e4cc59064b8f);
    }
    public function DropColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4)
    {
        return $this->real_db->DropColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4);
    }
    public function AlterColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_972817360b76b9fbe38abcddf8581926, $_5aa5dc9c9e309814b04c339cd29f3d88 = false)
    {
        return $this->real_db->AlterColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_972817360b76b9fbe38abcddf8581926, $_5aa5dc9c9e309814b04c339cd29f3d88);
    }
    public function RenameTable($_c81a475ecdc9121925813756400e25f9, $_3a74d656d808162f30e545b85244362e)
    {
        return $this->real_db->RenameTable($_c81a475ecdc9121925813756400e25f9, $_3a74d656d808162f30e545b85244362e);
    }
    public function cond_if(string $_a5a8b9d897aa719dd04368fc1d38aeda, string $_099592a3550c4145ddb0e0e7c6882138, string $_392bfbdfc4ba5cb727f7ca6c5961c380) : string
    {
        return $this->real_db->cond_if($_a5a8b9d897aa719dd04368fc1d38aeda, $_099592a3550c4145ddb0e0e7c6882138, $_392bfbdfc4ba5cb727f7ca6c5961c380);
    }
    protected function CreateResultObj($_1510936859caf133c4c43d176baacdd6, $_d88b50ddb42db648a9c7ac08065b9409)
    {
        return $this->real_db->CreateResultObj($_1510936859caf133c4c43d176baacdd6, $_d88b50ddb42db648a9c7ac08065b9409);
    }
    protected function GetDBError()
    {
        return $this->real_db->GetDBError();
    }
    protected function ExecuteQuery(DAL\Query2 $_b7c1ecdc394c975ec6981fc48096d2c8)
    {
        $_55f66c3c11d94d22f02e31da2cb21234 = $_b7c1ecdc394c975ec6981fc48096d2c8->_GetQuery();
        $this->query_log[] = array($_55f66c3c11d94d22f02e31da2cb21234, $_b7c1ecdc394c975ec6981fc48096d2c8->_GetBinds());
        return $this->real_db->ExecuteQuery($_b7c1ecdc394c975ec6981fc48096d2c8);
    }
    protected function add_join_conditions_to_query($_55f66c3c11d94d22f02e31da2cb21234, &$_043f14748699f452138b9cfe78e5e6bc)
    {
        return $this->real_db->add_join_conditions_to_query($_55f66c3c11d94d22f02e31da2cb21234, $_043f14748699f452138b9cfe78e5e6bc);
    }
    public function insertId()
    {
        return $this->real_db->insertId();
    }
    public function Date14ToUnix(string $_67a0d624aebcceb0abd5ce56a53ff06f) : string
    {
        return $this->real_db->Date14ToUnix($_67a0d624aebcceb0abd5ce56a53ff06f);
    }
    public function UnixToDate14(string $_67a0d624aebcceb0abd5ce56a53ff06f) : string
    {
        return $this->real_db->UnixToDate14($_67a0d624aebcceb0abd5ce56a53ff06f);
    }
    public function substring(string $_66824e0309bb76c78bd2bbd5fda8d3d8, int $_2cc1b85bbc9f36a91e2f3d508cf9bf8d, $_827a4ce5f334e525c32838c58787f831 = false) : string
    {
        return $this->real_db->substring($_66824e0309bb76c78bd2bbd5fda8d3d8, $_2cc1b85bbc9f36a91e2f3d508cf9bf8d, $_827a4ce5f334e525c32838c58787f831);
    }
    public function type() : string
    {
        return $this->real_db->type();
    }
    public function affected()
    {
        return $this->real_db->affected();
    }
    
    
    
    
    public function BeginTransaction()
    {
    }
    
    
    
    
    public function EndTransaction()
    {
    }
    
    
    
    
    public function RollbackTransaction()
    {
    }
    
    
    
    
    public function InTransaction() : bool
    {
        return false;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/DAL/Uninstall/UninstallDb.php <==
<?php
namespace Claromentis\Core\DAL\Uninstall;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] ?: array()) + array();
use Claromentis\Core\DAL;




class UninstallDb extends DAL\Db
{
    protected $error;
    protected $tables = array();
    protected $primary_keys = array();
    protected $indexes = array();
    
    
    
    
    protected $real_db;
    public $query_log = array();
    public function __construct(DAL\Db $_8bf9813aed9bb9b6d29793f34cc5e497)
    {
        parent::__construct();
        $this->query_parser = new DAL\QueryParser($_8bf9813aed9bb9b6d29793f34cc5e497);
        $this->real_db = $_8bf9813aed9bb9b6d29793f34cc5e497;
    }
    public function CreateTable($_c81a475ecdc9121925813756400e25f9, $_1d86cbeb8686a6ea980cae523fcc2663, $_2bd53affda468514082256f545d64e34 = false, $_6bfdb3fdd74d9a63f8a8594eeec07b71 = false)
    {
        return $this->real_db->CreateTable($_c81a475ecdc9121925813756400e25f9, $_1d86cbeb8686a6ea980cae523fcc2663, $_2bd53affda468514082256f545d64e34, $_6bfdb3fdd74d9a63f8a8594eeec07b71);
    }
    public function DropTable($_c81a475ecdc9121925813756400e25f9)
    {
        return $this->real_db->DropTable($_c81a475ecdc9121925813756400e25f9);
    }
    public function CreatePrimaryKey($_c81a475ecdc9121925813756400e25f9, ...$_a42c86642011ef739b88ee80672c387d)
    {
        return $this->real_db->CreatePrimaryKey($_c81a475ecdc9121925813756400e25f9, ...$_a42c86642011ef739b88ee80672c387d);
    }
    public function DropPrimaryKey($_c81a475ecdc9121925813756400e25f9)
    {
        return $this->real_db->DropPrimaryKey($_c81a475ecdc9121925813756400e25f9);
    }
    public function CreateIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea, ...$_a42c86642011ef739b88ee80672c387d)
    {
        return true;
    }
    public function DropIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea)
    {
        return $this->real_db->DropIndex($_c81a475ecdc9121925813756400e25f9, $_0f28da8a93097c24717c5f47b66ea3ea);
    }
    public function AddColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_b1ab3509f78a3004fac0e4cc59064b8f)
    {
        return $this->real_db->AddColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_b1ab3509f78a3004fac0e4cc59064b8f);
    }
    public function DropColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4)
    {
        return $this->real_db->DropColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4);
    }
    public function AlterColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_972817360b76b9fbe38abcddf8581926, $_5aa5dc9c9e309814b04c339cd29f3d88 = false)
    {
        return $this->real_db->AlterColumn($_c81a475ecdc9121925813756400e25f9, $_72309675a90c2bcb98b562bf18bb9da4, $_972817360b76b9fbe38abcddf8581926, $_5aa5dc9c9e309814b04c339cd29f3d88);
    }
    public function RenameTable($_c81a475ecdc9121925813756400e25f9, $_3a74d656d808162f30e545b85244362e)
    {
        return $this->real_db->RenameTable($_c81a475ecdc9121925813756400e25f9, $_3a74d656d808162f30e545b85244362e);
    }
    public function cond_if(string $_a5a8b9d897aa719dd04368fc1d38aeda, string $_099592a3550c4145ddb0e0e7c6882138, string $_392bfbdfc4ba5cb727f7ca6c5961c380) : string
    {
        return $this->real_db->cond_if($_a5a8b9d897aa719dd04368fc1d38aeda, $_099592a3550c4145ddb0e0e7c6882138, $_392bfbdfc4ba5cb727f7ca6c5961c380);
    }
    protected function CreateResultObj($_1510936859caf133c4c43d176baacdd6, $_d88b50ddb42db648a9c7ac08065b9409)
    {
        return $this->real_db->CreateResultObj($_1510936859caf133c4c43d176baacdd6, $_d88b50ddb42db648a9c7ac08065b9409);
    }
    protected function GetDBError()
    {
        return $this->real_db->GetDBError();
    }
    protected function ExecuteQuery(DAL\Query2 $_b7c1ecdc394c975ec6981fc48096d2c8)
    {
        $_55f66c3c11d94d22f02e31da2cb21234 = $_b7c1ecdc394c975ec6981fc48096d2c8->_GetQuery();
        $this->query_log[] = array($_55f66c3c11d94d22f02e31da2cb21234, $_b7c1ecdc394c975ec6981fc48096d2c8->_GetBinds());
        return $this->real_db->ExecuteQuery($_b7c1ecdc394c975ec6981fc48096d2c8);
    }
    protected function add_join_conditions_to_query($_55f66c3c11d94d22f02e31da2cb21234, &$_043f14748699f452138b9cfe78e5e6bc)
    {
        return $this->real_db->add_join_conditions_to_query($_55f66c3c11d94d22f02e31da2cb21234, $_043f14748699f452138b9cfe78e5e6bc);
    }
    public function insertId()
    {
        return $this->real_db->insertId();
    }
    public function Date14ToUnix(string $_67a0d624aebcceb0abd5ce56a53ff06f) : string
    {
        return $this->real_db->Date14ToUnix($_67a0d624aebcceb0abd5ce56a53ff06f);
    }
    public function UnixToDate14(string $_67a0d624aebcceb0abd5ce56a53ff06f) : string
    {
        return $this->real_db->UnixToDate14($_67a0d624aebcceb0abd5ce56a53ff06f);
    }
    public function substring(string $_66824e0309bb76c78bd2bbd5fda8d3d8, int $_2cc1b85bbc9f36a91e2f3d508cf9bf8d, $_827a4ce5f334e525c32838c58787f831 = false) : string
    {
        return $this->real_db->substring($_66824e0309bb76c78bd2bbd5fda8d3d8, $_2cc1b85bbc9f36a91e2f3d508cf9bf8d, $_827a4ce5f334e525c32838c58787f831);
    }
    public function type() : string
    {
        return $this->real_db->type();
    }
    public function affected()
    {
        return $this->real_db->affected();
    }
    
    
    
    
    public function BeginTransaction()
    {
    }
    
    
    
    
    public function EndTransaction()
    {
    }
    
    
    
    
    public function RollbackTransaction()
    {
    }
    
    
    
    
    public function InTransaction() : bool
    {
        return false;
    }
}
